Contribute
==========

You want to hack new features into km3pipe or are just here to fix a
bug? Great! Let's get you started.

If you have any questions, join us in the chat at https://chat.km3net.de, in the `#km3pipe`  channel.

.. toctree::
  dev
  doc
  logging
